package com.gic.haoban.manage.service.task;

import com.alibaba.fastjson.JSONObject;
import com.gic.binlog.base.entity.GicField;
import com.gic.binlog.base.entity.GicRecord;
import com.gic.binlog.base.entity.enums.GicRecordType;
import com.gic.commons.util.BeanUtil;
import com.gic.commons.util.EntityUtil;
import com.gic.haoban.manage.service.pojo.BinlogBasePojo;
import com.gic.haoban.manage.service.pojo.ClerkSyncPojo;
import com.gic.haoban.manage.service.service.StaffClerkRelationService;
import org.apache.commons.lang3.StringUtils;
import org.apache.kafka.clients.consumer.ConsumerRecord;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.kafka.listener.MessageListener;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * Created 2019/4/10.
 *
 * @author hua
 */
public class KafkaMessageServiceImpl implements MessageListener<String, GicRecord> {

    private final static Logger logger = LoggerFactory.getLogger(KafkaMessageServiceImpl.class);

    private  final String STORE = "tab_gic_store";

    private final  String CLERK = "tab_gic_clerk";

    @Autowired
    private StaffClerkRelationService staffClerkRelationService;


    @Override
    public void onMessage(ConsumerRecord<String, GicRecord> record) {
        logger.info("message：{}", JSONObject.toJSONString(record.value()));
        if(record.value()==null){
            logger.info("数据为空");
            return;
        }
        BinlogBasePojo pojo = binlogChange(record.value());
        logger.info("binlog数据：{}", JSONObject.toJSONString(pojo));

        if (record.value().getTableName().equals(CLERK)) {
            dealClerk((ClerkSyncPojo)pojo);
        }
    }

    private void dealClerk(ClerkSyncPojo syncPojo) {
        GicRecordType gicRecordType = GicRecordType.valueOf(syncPojo.getRecordType());
        if(gicRecordType.equals(GicRecordType.DELETE)){
            staffClerkRelationService.delBind(syncPojo.getClerkId());
        }else if (gicRecordType.equals(GicRecordType.INSERT)) {

        }
    }

    private BinlogBasePojo binlogChange(GicRecord record) {
        ClerkSyncPojo pojo=new ClerkSyncPojo();
        pojo.setRecordType(record.getRecordType().value());
        if(record.getTableName().equals(CLERK)) {
            return binlogMap(record.getFieldList(),record.getRecordType(),ClerkSyncPojo.class);
        }else if (record.getTableName().equals(STORE)) {
            return binlogMap(record.getFieldList(),record.getRecordType(),ClerkSyncPojo.class);
        }else{
            return null;
        }
    }

    private BinlogBasePojo binlogMap(List<GicField> list,GicRecordType recordType,Class<? extends BinlogBasePojo> aclass) {
        Map<String,String> mid=new HashMap<>();
        for (GicField gicField : list) {
            mid.put(gicField.getName(),gicField.getValue());
        }
        BinlogBasePojo pojo = EntityUtil.changeEntityByJSON(aclass, mid);
        pojo.setRecordType(recordType.value());
        return pojo;

    }


}
